==> remotable-plugins-plugin-0.8.1106.jar: all.js <==
(function(f){var e=f._AP?_AP:(f.RA=f.AP={});
var d={};
e.define=function(i,k,h){var j=c(i),g;
if(!h){h=k;
k=[]
}if(h){g=typeof h!=="function"?function(){return h
}:h;
b(k,function(){var m=g.apply(f,arguments);
if(m){if(typeof m==="function"){j.exports.__target__=m
}for(var l in m){if(m.hasOwnProperty(l)){j.exports[l]=m[l]
}}}})
}};
e.require=function(g,h){b(typeof g==="string"?[g]:g,h)
};
function b(l,m){var j=[],h=0,g=l.length;
function k(p){j.push(p);
if(j.length===g){var n=[],o=0;
for(;
o<g;
o+=1){n[o]=j[o].exports
}if(m){m.apply(f,n)
}}}if(l&&l.length>0){for(;
h<g;
h+=1){a(l[h],k)
}}else{if(m){m()
}}}function a(g,h){h(c(g))
}function c(g){return d[g]=d[g]||{name:g,exports:function(){function h(){var i=h.__target__;
if(i){return i.apply(f,arguments)
}}return h
}()}
}}(this));
AP.define("_util",function(){function c(g,f){var d,e;
if(g){d=g.length;
if(d!=null&&typeof g!=="function"){e=0;
while(e<d){if(f.call(g[e],e,g[e])===false){break
}e+=1
}}else{for(e in g){if(g.hasOwnProperty(e)){if(f.call(g[e],e,g[e])===false){break
}}}}}}function a(d,e){d+="EventListener";
e+="Event";
return function(g,h,f){if(g[d]){g[d](h,f,false)
}else{if(g[e]){g[e]("on"+h,f)
}}}
}function b(){var e=this.console;
if(e&&e.log){var f=[].slice.call(arguments);
if(e.log.apply){e.log.apply(e,f)
}else{for(var g=0,d=f.length;
g<d;
g+=1){f[g]=JSON.stringify(f[g])
}e.log(f.join(" "))
}return true
}}return{each:c,extend:function(e){var d=arguments,f=[].slice.call(d,1,d.length);
c(f,function(g,h){c(h,function(j,i){e[j]=i
})
});
return e
},bind:a("add","attach"),unbind:a("remove","detach"),trim:function(d){return d&&d.replace(/^\s+|\s+$/g,"")
},debounce:function(d,f){var e;
return function(){var g=this,i=[].slice.call(arguments);
function h(){e=null;
d.apply(g,i)
}if(e){clearTimeout(e)
}e=setTimeout(h,f||50)
}
},inArray:function(g,h,f){var e=f>>>0,d=h.length>>>0;
for(;
e<d;
e+=1){if(h[e]===g){return e
}}return -1
},isFunction:function(d){return typeof d==="function"
},log:b,handleError:function(d){if(!b.apply(this,d&&d.message?[d,d.message]:[d])){throw d
}}}
});
var request=AP.require("request");
AP.define("_ajax",["_util","env"],function(a,b){var c=this,d=c.JSON;
return{ajax:function(e){var g;
g=(c.ActiveXObject&&new ActiveXObject("Microsoft.XMLHTTP"));
if(!g){g=c.XMLHttpRequest&&new XMLHttpRequest()
}g.onreadystatechange=function(){if(g.readyState===4){var i=g.status,j=g.responseText,o=g.getResponseHeader("Content-Type"),n=function(){},m=e.success||n,k=e.error||n,h;
if(i>=200&&i<=300){if(o&&o.indexOf("application/json")===0){try{h=d.parse(j);
try{m(h,g.statusText)
}catch(l){a.handleError(l)
}}catch(l){k(g,"parseerror",l)
}}else{m(j,g.statusText)
}}else{k(g,g.statusText||"error")
}}};
g.open("GET",e.url,true);
var f=e.headers||{};
f["AP-Auth-State"]=b.meta("auth-state");
a.each(e.headers,function(i,h){g.setRequestHeader(i,h)
});
g.send(null);
return g
}}
});
AP.define("_dollar",["_util","_ajax"],function(b,f){var e=b.each,g=b.extend,c=this,a=c.document;
function d(k,j){j=j||a;
var i=[];
if(k){if(typeof k==="string"){var h=j.querySelectorAll(k);
e(h,function(m,l){i.push(l)
})
}else{if(k.nodeType===1){i.push(k)
}else{if(k===c){i.push(k)
}}}}g(i,{each:function(l){e(this,l);
return this
},bind:function(l,m){this.each(function(n,o){b.bind(o,l,m)
})
},attr:function(m){var l;
this.each(function(n,o){l=o[m]||(o.getAttribute&&o.getAttribute(m));
return !l
});
return l
},removeClass:function(l){return this.each(function(m,n){if(n.className){n.className=n.className.replace(new RegExp("(^|\\s)"+l+"(\\s|$)")," ")
}})
},html:function(l){return this.each(function(m,n){n.innerHTML=l
})
},append:function(l){return this.each(function(m,o){var n=j.createElement(l.tag);
e(l,function(q,p){if(q==="$text"){if(n.styleSheet){n.styleSheet.cssText=p
}else{n.appendChild(j.createTextNode(p))
}}else{if(q!=="tag"){n[q]=p
}}});
o.appendChild(n)
})
}});
return i
}return g(d,b,f)
});
(window.AP||window._AP).define("_xdm-rpc",["_dollar"],function(f){var j=window.location.toString(),l=0;
var c=f(window),h=f.isFunction;
function d(o,n){return decodeURIComponent(RegExp(n+"=([^&]+)").exec(o)[1])
}function k(p){var n=p.toLowerCase().match(/^((http.?:)\/\/([^:\/\s]+)(:\d+)*)/),q=n[2],r=n[3],o=n[4]||"";
if((q==="http:"&&o===":80")||(q==="https:"&&o===":443")){o=""
}return q+"//"+r+o
}function b(p,q){var o=p,n=/\?/.test(p)?"&":"?";
f.each(q,function(s,r){o+=n+encodeURIComponent(s)+"="+encodeURIComponent(r);
n="&"
});
return o
}function m(n){var o=document.createElement("iframe"),q="easyXDM_"+n.container+"_provider";
var p=b(n.remote,{xdm_e:k(j),xdm_c:n.channel,xdm_p:1});
f.extend(o,{id:q,name:q,frameBorder:"0"},n.props);
f("#"+n.container).append(o);
o.src=p;
return o
}function i(n){return n.message||n.toString()
}function a(){if(g.debug){e.apply(window,["DEBUG:"].concat([].slice.call(arguments)))
}}function e(){var n=f.log||(window.AJS&&window.AJS.log);
if(n){n.apply(window,arguments);
return true
}}function g(q,n){var D,o=(l+=1),x,A,y,B,p=n.local||{},w=n.remote||[];
var v=function(){function E(){var F={};
return function(H,G){if(h(G)){F[H]=G
}else{if(F[H]){F[H](G);
delete F[H]
}}}
}return{done:E(),fail:E()}
}();
if(!/xdm_e/.test(j)){var u=m(q);
x=u.contentWindow;
A=k(q.remote);
y=q.channel;
B={iframe:u,destroy:function(){C();
if(D.iframe){f(D.iframe).remove();
delete D.iframe
}},isActive:function(){return f.contains(document.documentElement,D.iframe)
}}
}else{x=window.parent;
A=d(j,"xdm_e");
y=d(j,"xdm_c");
B={isActive:function(){return true
}}
}D=f.extend({id:o,origin:A,channel:y},B);
function t(E,G,H){try{x.postMessage(JSON.stringify({c:y,i:E,t:G,m:H}),A)
}catch(F){e(i(F))
}}function r(L){function H(T){return function(U){t(J,T,U)
}
}try{var P=JSON.parse(L.data),J=P.i,K=P.c,S=P.t,Q=P.m;
if(L.source!==x||L.origin!==A||K!==y){return
}if(S==="request"){var E=Q.n,N=Q.a,O=p[E],I,F,G;
if(O){I=H("done");
F=H("fail");
G=(N?N.length:0)<O.length;
try{if(G){O.apply(p,N.concat([I,F]))
}else{I(O.apply(p,N))
}}catch(M){F(i(M))
}}else{a("Unhandled request:",P)
}}else{if(S==="done"||S==="fail"){var R=v[S];
if(R){R(J,Q)
}else{a("Unhandled response:",P)
}}}}catch(M){e(i(M))
}}f.each(w,function(F,E){if(typeof F==="number"){F=E
}D[F]=function(){var I=[].slice.call(arguments),H,G;
function J(){if(h(I[I.length-1])){return I.pop()
}}G=J();
H=J();
if(!H){H=G;
G=undefined
}var K=Math.floor(Math.random()*1000000000).toString(16);
if(H){v.done(K,H)
}if(G){v.fail(K,G)
}t(K,"request",{n:F,a:I})
}
});
function s(E){if(D.isActive()){r(E.originalEvent?E.originalEvent:E)
}else{C()
}}function z(){c.bind("message",s)
}function C(){c.unbind("message",s)
}z();
return D
}return g
});
AP.define("_rpc",["_dollar","_xdm-rpc"],function(b,c){var l=b.each,j=b.extend,d=b.isFunction,k={},e,f={},a=["init"],g={},i=[],h;
return{extend:function(m){if(d(m)){m=m(k)
}j(f,m.apis);
j(g,m.internals);
a=a.concat(m.stubs||[]);
var n=m.init;
if(d(n)){i.push(n)
}return m.apis
},init:function(n){n=n||{};
if(!h){var m={};
l(f,function(o){a.push(o)
});
e=new c(m,{remote:a,local:g});
e.init();
j(k,e);
l(i,function(o,q){try{q(j({},n))
}catch(p){b.handleError(p)
}});
h=true
}}}
});
AP.define("env",["_dollar","_rpc"],function(b,c){var a=c.extend(function(d){return{apis:{getLocation:function(e){d.getLocation(e)
},getUser:function(e){d.getUser(e)
},getTimeZone:function(e){d.getTimeZone(e)
},fireEvent:function(f,e){d.fireEvent(f,e)
},showMessage:function(g,f,e){d.showMessage(g,f,e)
},clearMessage:function(e){d.clearMessage(e)
},resize:b.debounce(function(f,e){var g=a.size(f,e);
d.resize(g.w,g.h)
},50)}}
});
return b.extend(a,{meta:function(d){return b("meta[name='ap-"+d+"']").attr("content")
},localUrl:function(d){return this.meta("local-base-url")+(d==null?"":d)
},size:function(d,o){var m=d==null?"100%":d,k=Math.max,i=document.body,n=document.documentElement,l="scrollHeight",f="offsetHeight",e="clientHeight",j=k(n[e],i[l],n[l],i[f],n[f]),g=o==null?j:o;
return{w:m,h:g}
}})
});
AP.define("request",["_dollar","_rpc"],function(d,e){var c=d.each,f=d.extend;
function b(g){var i=f({},g);
var h=g.headers||{};
delete i.headers;
return f(i,{getResponseHeader:function(j){var k=null;
if(j){j=j.toLowerCase();
c(h,function(m,l){if(m.toLowerCase()===j){k=l;
return false
}})
}return k
},getAllResponseHeaders:function(){var j="";
c(h,function(m,l){j+=(j?"\r\n":"")+m+": "+l
});
return j
}})
}var a=e.extend(function(g){return{apis:{request:function(l,k){var m,j;
function i(o){return m(o[0],o[1],b(o[2]))
}function h(o){return j(b(o[0]),o[1],o[2])
}if(typeof l==="object"){k=l
}else{if(!k){k={url:l}
}else{k.url=l
}}function n(){}m=k.success||n;
delete k.success;
j=k.error||n;
delete k.error;
g.request(k,i,h)
}}}
});
return a.request
});
AP.define("dialog",["_dollar","_rpc"],function(c,d){var a=window.location.toString().indexOf("dialog=1")>0,b;
d.extend(function(f){var e={};
b={isDialog:a,onDialogMessage:function(g,h){this.getButton(g).bind(h)
},getButton:function(g){return{name:g,enable:function(){f.setDialogButtonEnabled(g,true)
},disable:function(){f.setDialogButtonEnabled(g,false)
},toggle:function(){var h=this;
h.isEnabled(function(i){h[i?"disable":"enable"](g)
})
},isEnabled:function(h){f.isDialogButtonEnabled(g,h)
},bind:function(i){var h=e[g];
if(!h){h=e[g]=[]
}h.push(i)
},trigger:function(){var j=this,i=true,h=true,k=e[g];
c.each(k,function(l,m){h=m.call(j,{button:j,stopPropagation:function(){i=false
}});
return i
});
return !!h
}}
}};
return{internals:{dialogMessage:function(h){var g=true;
try{if(a){g=b.getButton(h).trigger()
}else{c.handleError("Received unexpected dialog button event from host:",h)
}}catch(i){c.handleError(i)
}return g
}},stubs:["setDialogButtonEnabled","isDialogButtonEnabled"]}
});
return b
});
AP.define("bigpipe",["_dollar","env"],function(d,b){var c=d.each;
function e(){var l,j,i={},f={},p={},g=0;
function k(q){d.ajax({url:q+"/"+(g+=1),headers:{Accept:"application/json"},success:function(r){o(r,q)
},error:function(t,r,s){if(t.status!==200){o({items:[],pending:[]},q)
}else{d.handleError(s||(t&&t.responseText)||r)
}}})
}function o(r,s){if(r){var q=r.items;
var t=r.pending;
if(q.length>0||t.length>0){c(q,function(u,v){h(v)
});
if(t.length>0){c(i,function(v,u){if(u&&d.inArray(v,t)<0){n(v)
}});
k(s)
}else{n()
}}else{if(!j){n()
}}}}function h(q){var r=q.channelId;
i[r]=true;
if(f[r]){f[r](q)
}else{(p[r]=p[r]||[]).push(q)
}}function n(q){if(q){h({channelId:q,complete:true});
delete f[q];
i[q]=false
}else{if(!j){c(f,n);
j=true
}}}var m={start:function(q){q=q||{};
var s=q.localBaseUrl||b.meta("local-base-url");
var t=q.requestId;
if(!l&&s&&t){var r=q.ready||{items:[],pending:[0]};
o(r,s+"/bigpipe/request/"+t);
l=true
}return m
},subscribe:function(r,q){if(f[r]){throw new Error("Channel '"+r+"' already has a subscriber")
}if(q){f[r]=q;
c(p[r],function(s,t){h(t)
});
delete p[r];
if(j){n(r)
}}return m
}};
return m
}var a=e();
a.subscribe("html",function(f){if(!f.complete){d("#"+f.contentId).removeClass("bp-loading").html(f.content);
b.resize()
}});
return d.extend(e,a)
});
AP.define("jira",["_dollar","_rpc"],function(b,g){function f(){return decodeURI(RegExp("remoteWorkflowPostFunctionUUID=([0-9a-z-]+)").exec(document.location)[1])
}var e,d;
var c={onSaveValidation:function(h){d=h
},onSave:function(h){e=h
},trigger:function(){var i=d.call(),h;
return{valid:i,uuid:i?f():h,value:i?""+e.call():h}
}};
var a=g.extend(function(h){return{apis:{getWorkflowConfiguration:function(i){h.getWorkflowConfiguration(f(),i)
}},internals:{setWorkflowConfigurationMessage:function(){return c.trigger()
}}}
});
return b.extend(a,{WorkflowConfiguration:c})
});
AP.require(["_dollar","_rpc","env","request","dialog","bigpipe","jira"],function(e,f,g,d,i,h,c){function a(){g.getLocation(function(m){e("head").append({tag:"base",href:m,target:"_parent"})
})
}function k(){var m=i.isDialog?"10px 10px 0 10px":"0";
e("head").append({tag:"style",type:"text/css",$text:"body {margin: "+m+" !important;}"})
}f.extend({init:function(m){if(m.margin!==false){k(m)
}if(m.base===true){a(m)
}if(m.resize!==false){var n=m.resize;
n=n==="auto"?125:+n;
if(n>=0&&n<60){n=60
}if(!i.isDialog&&n>0){e.bind(window,"load",function(){var o;
setInterval(function(){var p=g.size();
if(!o||o.w!==p.w||o.h!==p.h){g.resize(p.w,p.h);
o=p
}},n)
})
}else{e.bind(window,"load",function(){g.resize()
})
}}}});
e.extend(AP,g,c,{Meta:{get:g.meta},request:d,Dialog:i,BigPipe:h});
var l={},b=e("script[src*='/remotable-plugins/all']");
if(b&&/\/remotable-plugins\/all(-debug)?\.js($|\?)/.test(b.attr("src"))){var j=b.attr("data-options");
if(j){e.each(j.split(";"),function(r,q){var m=e.trim;
q=m(q);
if(q){var p=q.split(":"),o=m(p[0]),n=m(p[1]);
if(o&&n!=null){l[o]=n==="true"||n==="false"?n==="true":n
}}})
}}f.init(l)
});

==> remotable-plugins-plugin-0.9.1154.jar: all.js <==
(function(f){var e=f._AP?_AP:(f.RA=f.AP={});
var d={};
e.define=function(i,k,h){var j=c(i),g;
if(!h){h=k;
k=[]
}if(h){g=typeof h!=="function"?function(){return h
}:h;
b(k,function(){var m=g.apply(f,arguments);
if(m){if(typeof m==="function"){j.exports.__target__=m
}for(var l in m){if(m.hasOwnProperty(l)){j.exports[l]=m[l]
}}}})
}};
e.require=function(g,h){b(typeof g==="string"?[g]:g,h)
};
function b(l,m){var j=[],h=0,g=l.length;
function k(p){j.push(p);
if(j.length===g){var n=[],o=0;
for(;
o<g;
o+=1){n[o]=j[o].exports
}if(m){m.apply(f,n)
}}}if(l&&l.length>0){for(;
h<g;
h+=1){a(l[h],k)
}}else{if(m){m()
}}}function a(g,h){h(c(g))
}function c(g){return d[g]=d[g]||{name:g,exports:function(){function h(){var i=h.__target__;
if(i){return i.apply(f,arguments)
}}return h
}()}
}}(this));
AP.define("_util",function(){function c(g,f){var d,e;
if(g){d=g.length;
if(d!=null&&typeof g!=="function"){e=0;
while(e<d){if(f.call(g[e],e,g[e])===false){break
}e+=1
}}else{for(e in g){if(g.hasOwnProperty(e)){if(f.call(g[e],e,g[e])===false){break
}}}}}}function a(d,e){d+="EventListener";
e+="Event";
return function(g,h,f){if(g[d]){g[d](h,f,false)
}else{if(g[e]){g[e]("on"+h,f)
}}}
}function b(){var e=this.console;
if(e&&e.log){var f=[].slice.call(arguments);
if(e.log.apply){e.log.apply(e,f)
}else{for(var g=0,d=f.length;
g<d;
g+=1){f[g]=JSON.stringify(f[g])
}e.log(f.join(" "))
}return true
}}return{each:c,extend:function(e){var d=arguments,f=[].slice.call(d,1,d.length);
c(f,function(g,h){c(h,function(j,i){e[j]=i
})
});
return e
},bind:a("add","attach"),unbind:a("remove","detach"),trim:function(d){return d&&d.replace(/^\s+|\s+$/g,"")
},debounce:function(d,f){var e;
return function(){var g=this,i=[].slice.call(arguments);
function h(){e=null;
d.apply(g,i)
}if(e){clearTimeout(e)
}e=setTimeout(h,f||50)
}
},inArray:function(g,h,f){var e=f>>>0,d=h.length>>>0;
for(;
e<d;
e+=1){if(h[e]===g){return e
}}return -1
},isFunction:function(d){return typeof d==="function"
},log:b,handleError:function(d){if(!b.apply(this,d&&d.message?[d,d.message]:[d])){throw d
}}}
});
AP.define("_dollar",["_util"],function(b){var e=b.each,f=b.extend,c=this,a=c.document;
function d(j,i){i=i||a;
var h=[];
if(j){if(typeof j==="string"){var g=i.querySelectorAll(j);
e(g,function(l,k){h.push(k)
})
}else{if(j.nodeType===1){h.push(j)
}else{if(j===c){h.push(j)
}}}}f(h,{each:function(k){e(this,k);
return this
},bind:function(k,l){this.each(function(m,n){b.bind(n,k,l)
})
},attr:function(m){var l;
this.each(function(k,n){l=n[m]||(n.getAttribute&&n.getAttribute(m));
return !l
});
return l
},removeClass:function(k){return this.each(function(l,m){if(m.className){m.className=m.className.replace(new RegExp("(^|\\s)"+k+"(\\s|$)")," ")
}})
},html:function(k){return this.each(function(l,m){m.innerHTML=k
})
},append:function(k){return this.each(function(l,n){var m=i.createElement(k.tag);
e(k,function(p,o){if(p==="$text"){if(m.styleSheet){m.styleSheet.cssText=o
}else{m.appendChild(i.createTextNode(o))
}}else{if(p!=="tag"){m[p]=o
}}});
n.appendChild(m)
})
}});
return h
}return f(d,b)
});
(window.AP||window._AP).define("_xdm-rpc",["_dollar"],function(f){var j=window.location.toString(),l=0;
var c=f(window),h=f.isFunction;
function d(o,n){return decodeURIComponent(RegExp(n+"=([^&]+)").exec(o)[1])
}function k(p){var n=p.toLowerCase().match(/^((http.?:)\/\/([^:\/\s]+)(:\d+)*)/),q=n[2],r=n[3],o=n[4]||"";
if((q==="http:"&&o===":80")||(q==="https:"&&o===":443")){o=""
}return q+"//"+r+o
}function b(p,q){var o=p,n=/\?/.test(p)?"&":"?";
f.each(q,function(s,r){o+=n+encodeURIComponent(s)+"="+encodeURIComponent(r);
n="&"
});
return o
}function m(n){var o=document.createElement("iframe"),q="easyXDM_"+n.container+"_provider";
var p=b(n.remote,{xdm_e:k(j),xdm_c:n.channel,xdm_p:1});
f.extend(o,{id:q,name:q,frameBorder:"0"},n.props);
f("#"+n.container).append(o);
o.src=p;
return o
}function i(n){return n.message||n.toString()
}function a(){if(g.debug){e.apply(window,["DEBUG:"].concat([].slice.call(arguments)))
}}function e(){var n=f.log||(window.AJS&&window.AJS.log);
if(n){n.apply(window,arguments);
return true
}}function g(q,n){var D,o=(l+=1),x,A,y,B,p=n.local||{},w=n.remote||[];
var v=function(){function E(){var F={};
return function(H,G){if(h(G)){F[H]=G
}else{if(F[H]){F[H](G);
delete F[H]
}}}
}return{done:E(),fail:E()}
}();
if(!/xdm_e/.test(j)){var u=m(q);
x=u.contentWindow;
A=k(q.remote);
y=q.channel;
B={iframe:u,destroy:function(){C();
if(D.iframe){f(D.iframe).remove();
delete D.iframe
}},isActive:function(){return f.contains(document.documentElement,D.iframe)
}}
}else{x=window.parent;
A=d(j,"xdm_e");
y=d(j,"xdm_c");
B={isActive:function(){return true
}}
}D=f.extend({id:o,origin:A,channel:y},B);
function t(E,G,H){try{x.postMessage(JSON.stringify({c:y,i:E,t:G,m:H}),A)
}catch(F){e(i(F))
}}function r(L){function H(T){return function(U){t(J,T,U)
}
}try{var P=JSON.parse(L.data),J=P.i,K=P.c,S=P.t,Q=P.m;
if(L.source!==x||L.origin!==A||K!==y){return
}if(S==="request"){var E=Q.n,N=Q.a,O=p[E],I,F,G;
if(O){I=H("done");
F=H("fail");
G=(N?N.length:0)<O.length;
try{if(G){O.apply(p,N.concat([I,F]))
}else{I(O.apply(p,N))
}}catch(M){F(i(M))
}}else{a("Unhandled request:",P)
}}else{if(S==="done"||S==="fail"){var R=v[S];
if(R){R(J,Q)
}else{a("Unhandled response:",P)
}}}}catch(M){e(i(M))
}}f.each(w,function(F,E){if(typeof F==="number"){F=E
}D[F]=function(){var I=[].slice.call(arguments),H,G;
function J(){if(h(I[I.length-1])){return I.pop()
}}G=J();
H=J();
if(!H){H=G;
G=undefined
}var K=Math.floor(Math.random()*1000000000).toString(16);
if(H){v.done(K,H)
}if(G){v.fail(K,G)
}t(K,"request",{n:F,a:I})
}
});
function s(E){if(D.isActive()){r(E.originalEvent?E.originalEvent:E)
}else{C()
}}function z(){c.bind("message",s)
}function C(){c.unbind("message",s)
}z();
return D
}return g
});
AP.define("_rpc",["_dollar","_xdm-rpc"],function(b,c){var l=b.each,j=b.extend,d=b.isFunction,k={},e,f={},a=["init"],g={},i=[],h;
return{extend:function(m){if(d(m)){m=m(k)
}j(f,m.apis);
j(g,m.internals);
a=a.concat(m.stubs||[]);
var n=m.init;
if(d(n)){i.push(n)
}return m.apis
},init:function(n){n=n||{};
if(!h){var m={};
l(f,function(o){a.push(o)
});
e=new c(m,{remote:a,local:g});
e.init();
j(k,e);
l(i,function(o,q){try{q(j({},n))
}catch(p){b.handleError(p)
}});
h=true
}}}
});
AP.define("env",["_dollar","_rpc"],function(b,c){var a=c.extend(function(d){return{apis:{getLocation:function(e){d.getLocation(e)
},getUser:function(e){d.getUser(e)
},getTimeZone:function(e){d.getTimeZone(e)
},fireEvent:function(f,e){d.fireEvent(f,e)
},showMessage:function(g,f,e){d.showMessage(g,f,e)
},clearMessage:function(e){d.clearMessage(e)
},resize:b.debounce(function(f,e){var g=a.size(f,e);
d.resize(g.w,g.h)
},50)}}
});
return b.extend(a,{meta:function(d){return b("meta[name='ap-"+d+"']").attr("content")
},localUrl:function(d){return this.meta("local-base-url")+(d==null?"":d)
},size:function(d,o){var m=d==null?"100%":d,k=Math.max,i=document.body,n=document.documentElement,l="scrollHeight",f="offsetHeight",e="clientHeight",j=k(n[e],i[l],n[l],i[f],n[f]),g=o==null?j:o;
return{w:m,h:g}
}})
});
AP.define("request",["_dollar","_rpc"],function(d,e){var c=d.each,f=d.extend;
function b(g){var i=f({},g);
var h=g.headers||{};
delete i.headers;
return f(i,{getResponseHeader:function(j){var k=null;
if(j){j=j.toLowerCase();
c(h,function(m,l){if(m.toLowerCase()===j){k=l;
return false
}})
}return k
},getAllResponseHeaders:function(){var j="";
c(h,function(m,l){j+=(j?"\r\n":"")+m+": "+l
});
return j
}})
}var a=e.extend(function(g){return{apis:{request:function(l,k){var m,j;
function i(o){return m(o[0],o[1],b(o[2]))
}function h(o){return j(b(o[0]),o[1],o[2])
}if(typeof l==="object"){k=l
}else{if(!k){k={url:l}
}else{k.url=l
}}function n(){}m=k.success||n;
delete k.success;
j=k.error||n;
delete k.error;
g.request(k,i,h)
}}}
});
return a.request
});
AP.define("dialog",["_dollar","_rpc"],function(c,d){var a=window.location.toString().indexOf("dialog=1")>0,b;
d.extend(function(f){var e={};
b={isDialog:a,onDialogMessage:function(g,h){this.getButton(g).bind(h)
},getButton:function(g){return{name:g,enable:function(){f.setDialogButtonEnabled(g,true)
},disable:function(){f.setDialogButtonEnabled(g,false)
},toggle:function(){var h=this;
h.isEnabled(function(i){h[i?"disable":"enable"](g)
})
},isEnabled:function(h){f.isDialogButtonEnabled(g,h)
},bind:function(i){var h=e[g];
if(!h){h=e[g]=[]
}h.push(i)
},trigger:function(){var j=this,i=true,h=true,k=e[g];
c.each(k,function(l,m){h=m.call(j,{button:j,stopPropagation:function(){i=false
}});
return i
});
return !!h
}}
}};
return{internals:{dialogMessage:function(h){var g=true;
try{if(a){g=b.getButton(h).trigger()
}else{c.handleError("Received unexpected dialog button event from host:",h)
}}catch(i){c.handleError(i)
}return g
}},stubs:["setDialogButtonEnabled","isDialogButtonEnabled"]}
});
return b
});
AP.define("jira",["_dollar","_rpc"],function(b,g){function f(){return decodeURI(RegExp("remoteWorkflowPostFunctionUUID=([0-9a-z-]+)").exec(document.location)[1])
}var e,d;
var c={onSaveValidation:function(h){d=h
},onSave:function(h){e=h
},trigger:function(){var i=d.call(),h;
return{valid:i,uuid:i?f():h,value:i?""+e.call():h}
}};
var a=g.extend(function(h){return{apis:{getWorkflowConfiguration:function(i){h.getWorkflowConfiguration(f(),i)
}},internals:{setWorkflowConfigurationMessage:function(){return c.trigger()
}}}
});
return b.extend(a,{WorkflowConfiguration:c})
});
AP.require(["_dollar","_rpc","env","request","dialog","jira"],function(e,f,g,d,h,c){function a(){g.getLocation(function(l){e("head").append({tag:"base",href:l,target:"_parent"})
})
}function j(){var l=h.isDialog?"10px 10px 0 10px":"0";
e("head").append({tag:"style",type:"text/css",$text:"body {margin: "+l+" !important;}"})
}f.extend({init:function(l){if(l.margin!==false){j(l)
}if(l.base===true){a(l)
}if(l.resize!==false){var m=l.resize;
m=m==="auto"?125:+m;
if(m>=0&&m<60){m=60
}if(!h.isDialog&&m>0){e.bind(window,"load",function(){var n;
setInterval(function(){var o=g.size();
if(!n||n.w!==o.w||n.h!==o.h){g.resize(o.w,o.h);
n=o
}},m)
})
}else{e.bind(window,"load",function(){g.resize()
})
}}}});
e.extend(AP,g,c,{Meta:{get:g.meta},request:d,Dialog:h});
var k={},b=e("script[src*='/remotable-plugins/all']");
if(b&&/\/remotable-plugins\/all(-debug)?\.js($|\?)/.test(b.attr("src"))){var i=b.attr("data-options");
if(i){e.each(i.split(";"),function(q,p){var l=e.trim;
p=l(p);
if(p){var o=p.split(":"),n=l(o[0]),m=l(o[1]);
if(n&&m!=null){k[n]=m==="true"||m==="false"?m==="true":m
}}})
}}f.init(k)
});
